@@ -1,6 +1,7 @@
 ;;; viper-keym.el --- Viper keymaps
 
-;; Copyright (C) 1994, 95, 96, 97, 2000, 01, 02, 2005 Free Software Foundation, Inc.
+;; Copyright (C) 1994, 1995, 1996, 1997, 2000, 2001, 2002, 2003, 2004,
+;;   2005, 2006, 2007 Free Software Foundation, Inc.
 
 ;; Author: Michael Kifer <kifer@cs.stonybrook.edu>
 
@@ -143,7 +144,7 @@ viper-insert-basic-map.  Not recommended, except for novice users.")
   "Auxiliary map for global user-defined bindings in Emacs state.")
 
 (defvar  viper-emacs-kbd-map  (make-sparse-keymap)
-  "This keymap keeps Vi-style kbd macros for emacs mode.")
+  "This keymap keeps Vi-style kbd macros for Emacs mode.")
 
 (viper-deflocalvar viper-emacs-local-user-map  (make-sparse-keymap)
   "Auxiliary map for local user-defined bindings in Emacs state.")
@@ -159,10 +160,10 @@ viper-insert-basic-map.  Not recommended, except for novice users.")
 
 ;; Some important keys used in viper
 (defcustom viper-toggle-key [(control ?z)]  ; "\C-z"
-  "The key used to change states from emacs to Vi and back.
+  "The key used to change states from Emacs to Vi and back.
 In insert mode, this key also functions as Meta.
 
-Enter as a sexp. Examples: \"\\C-z\", [(control ?z)]."
+Enter as a sexp.  Examples: \"\\C-z\", [(control ?z)]."
   :type 'sexp
   :group 'viper
   :set (lambda (symbol value)
@@ -199,9 +200,10 @@ Enter as a sexp. Examples: \"\\C-z\", [(control ?z)]."
   :type 'string
   :group 'viper)
 
-(defcustom viper-ESC-key [(escape)]  ; "\e"
+(defcustom viper-ESC-key (if (viper-window-display-p) [(escape)] "\e")
   "Key used to ESC.
-Enter as a sexp. Examples: \"\\e\", [(escape)]."
+Enter as a sexp. Examples: \"\\e\", [(escape)].
+If running in a terminal, [(escape)] is not understood, so must use \"\\e\"."
   :type 'sexp
   :group 'viper
   :set (lambda (symbol value)
@@ -306,8 +308,6 @@ Enter as a sexp. Examples: \"\\e\", [(escape)]."
 (define-key viper-insert-basic-map "\C-d" 'viper-backward-indent)
 (define-key viper-insert-basic-map "\C-w" 'viper-delete-backward-word)
 (define-key viper-insert-basic-map "\C-t" 'viper-forward-indent)
-(define-key viper-insert-basic-map
-  (if viper-xemacs-p [(shift tab)] [S-tab]) 'viper-insert-tab)
 (define-key viper-insert-basic-map viper-quoted-insert-key 'quoted-insert)
 (define-key viper-insert-basic-map "\C-?" 'viper-del-backward-char-in-insert)
 (define-key viper-insert-basic-map [backspace] 'viper-del-backward-char-in-insert)
@@ -339,8 +339,8 @@ Enter as a sexp. Examples: \"\\e\", [(escape)]."
 (define-key viper-vi-basic-map "\C-m" 'viper-next-line-at-bol)
 (define-key viper-vi-basic-map "\C-u" 'viper-scroll-down)
 (define-key viper-vi-basic-map "\C-y" 'viper-scroll-down-one)
-(define-key viper-vi-basic-map "\C-s" 'viper-isearch-forward)
-(define-key viper-vi-basic-map "\C-r" 'viper-isearch-backward)
+;;(define-key viper-vi-basic-map "\C-s" 'viper-isearch-forward)
+;;(define-key viper-vi-basic-map "\C-r" 'viper-isearch-backward)
 (define-key viper-vi-basic-map "\C-c/" 'viper-toggle-search-style)
 (define-key viper-vi-basic-map "\C-c\C-g" 'viper-info-on-file)
 
