@@ -4,7 +4,7 @@
 ;;		 Viper Is also a Package for Emacs Rebels.
 
 ;; Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002,
-;;   2003, 2004, 2005, 2006 Free Software Foundation, Inc.
+;;   2003, 2004, 2005, 2006, 2007 Free Software Foundation, Inc.
 
 ;; Author: Michael Kifer <kifer@cs.stonybrook.edu>
 ;; Keywords: emulations
@@ -298,7 +298,6 @@
 ;;; Code:
 
 (require 'advice)
-(require 'cl)
 (require 'ring)
 
 ;; compiler pacifier
@@ -325,7 +324,7 @@
 
 ;; better be defined before Viper custom group.
 (defvar viper-custom-file-name (convert-standard-filename "~/.viper")
-  "Viper customisation file.
+  "Viper customization file.
 If set by the user, this must be done _before_ Viper is loaded in `~/.emacs'.")
 
 (defgroup viper nil
@@ -360,7 +359,7 @@ user decide when to invoke Viper in a major mode."
 			    (t 'ask))
   "To Viperize or not to Viperize.
 If t, viperize Emacs.  If nil -- don't.  If `ask', ask the user.
-This variable is used primatily when Viper is being loaded.
+This variable is used primarily when Viper is being loaded.
 
 Must be set in `~/.emacs' before Viper is loaded.
 DO NOT set this variable interactively, unless you are using the customization
@@ -457,6 +456,7 @@ unless it is coming up in a wrong Viper state."
 (defcustom viper-insert-state-mode-list
   '(internal-ange-ftp-mode
     comint-mode
+    gud-mode
     inferior-emacs-lisp-mode
     erc-mode
     eshell-mode
@@ -481,6 +481,7 @@ unless it is coming up in a wrong Viper state."
   '((help-mode emacs-state viper-slash-and-colon-map)
     (comint-mode insert-state viper-comint-mode-modifier-map)
     (comint-mode vi-state viper-comint-mode-modifier-map)
+    (gud-mode insert-state viper-comint-mode-modifier-map)
     (shell-mode insert-state viper-comint-mode-modifier-map)
     (inferior-emacs-lisp-mode insert-state viper-comint-mode-modifier-map)
     (shell-mode vi-state viper-comint-mode-modifier-map)
@@ -532,7 +533,7 @@ If Viper is enabled, turn it off.  Otherwise, turn it on."
 
 ;;;###autoload
 (defun viper-mode ()
-  "Turn on Viper emulation of Vi in Emacs. See Info node `(viper)Viper'."
+  "Turn on Viper emulation of Vi in Emacs. See Info node `(viper)Top'."
   (interactive)
   (if (not noninteractive)
       (progn
@@ -1027,14 +1028,46 @@ It also can't undo some Viper settings."
 
   (defadvice describe-key (before viper-describe-key-ad protect activate)
     "Force to read key via `viper-read-key-sequence'."
-    (interactive (list (viper-read-key-sequence "Describe key: "))
-		 ))
+    (interactive (let (key)
+		   (setq key (viper-read-key-sequence
+			      "Describe key (or click or menu item): "))
+		   (list key
+			 (prefix-numeric-value current-prefix-arg)
+			 ;; If KEY is a down-event, read also the
+			 ;; corresponding up-event.
+			 (and (vectorp key)
+			      (let ((last-idx (1- (length key))))
+				(and (eventp (aref key last-idx))
+				     (memq 'down (event-modifiers
+						  (aref key last-idx)))))
+			      (or (and (eventp (aref key 0))
+				       (memq 'down (event-modifiers
+						    (aref key 0)))
+				       ;; For the C-down-mouse-2 popup
+				       ;; menu, there is no subsequent up-event.
+				       (= (length key) 1))
+				  (and (> (length key) 1)
+				       (eventp (aref key 1))
+				       (memq 'down (event-modifiers (aref key 1)))))
+			      (read-event))))))
 
   (defadvice describe-key-briefly
     (before viper-describe-key-briefly-ad protect activate)
     "Force to read key via `viper-read-key-sequence'."
-    (interactive (list (viper-read-key-sequence "Describe key briefly: "))))
-
+    (interactive (let (key)
+		   (setq key (viper-read-key-sequence
+			      "Describe key (or click or menu item): "))
+		   ;; If KEY is a down-event, read and discard the
+		   ;; corresponding up-event.
+		   (and (vectorp key)
+			(let ((last-idx (1- (length key))))
+			  (and (eventp (aref key last-idx))
+			       (memq 'down (event-modifiers (aref key last-idx)))))
+			(read-event))
+		   (list key
+			 (if current-prefix-arg
+			     (prefix-numeric-value current-prefix-arg))
+			 1))))
 
   (defadvice find-file (before viper-add-suffix-advice activate)
     "Use `read-file-name' for reading arguments."
